macro_rules! all_variants {
($mac:ident, $($args:tt)*) => { ... };
}Expand description
All variant names in one place for the dispatch macros.
macro_rules! all_variants {
($mac:ident, $($args:tt)*) => { ... };
}All variant names in one place for the dispatch macros.